==> jc-1.4.0.tar.gz: javax/swing/FocusManager.h <==
// public abstract class javax.swing.FocusManager

// class file dependencies
// @dep_class bd8f813050148ee1 java_awt_DefaultKeyboardFocusManager
// @dep_class 3c8264cdfd76a265 java_awt_KeyboardFocusManager
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6d7c3f688095f3e7 javax_swing_FocusManager

// header file dependencies
// @dep_header java_awt_DefaultKeyboardFocusManager

#include "java/awt/DefaultKeyboardFocusManager.h"

#ifndef _JC_javax_swing_FocusManager_H_
#define _JC_javax_swing_FocusManager_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_event_KeyEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_FocusManager$object;

// Typedefs
typedef struct _jc_javax_swing_FocusManager$sub_refs	_jc_javax_swing_FocusManager$sub_refs;
typedef struct _jc_javax_swing_FocusManager$sub_nonrefs	_jc_javax_swing_FocusManager$sub_nonrefs;
typedef struct _jc_javax_swing_FocusManager$refs	_jc_javax_swing_FocusManager$refs;
typedef struct _jc_javax_swing_FocusManager$nonrefs	_jc_javax_swing_FocusManager$nonrefs;
typedef struct _jc_javax_swing_FocusManager$object	_jc_javax_swing_FocusManager$object;

typedef struct _jc_javax_swing_FocusManager$fields_struct	_jc_javax_swing_FocusManager$fields_struct;
typedef const struct _jc_javax_swing_FocusManager$vmethods	_jc_javax_swing_FocusManager$vmethods;
typedef const struct _jc_javax_swing_FocusManager$vtable	_jc_javax_swing_FocusManager$vtable;
typedef const struct _jc_javax_swing_FocusManager$vtype	_jc_javax_swing_FocusManager$vtype;

// Class fields structure
struct _jc_javax_swing_FocusManager$fields_struct {
	struct _jc_java_lang_String$object	*FOCUS__5fMANAGER__5fCLASS__5fPROPERTY;
};
extern _jc_javax_swing_FocusManager$fields_struct _jc_javax_swing_FocusManager$class_fields;

// Constructors
extern void _jc_javax_swing_FocusManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_FocusManager$object *);

// Virtual methods
extern void _jc_javax_swing_FocusManager$method$focusNextComponent$7bc09eefe16e9c64(_jc_env *, struct _jc_javax_swing_FocusManager$object *, struct _jc_java_awt_Component$object *);
extern void _jc_javax_swing_FocusManager$method$focusPreviousComponent$693af46b828c4036(_jc_env *, struct _jc_javax_swing_FocusManager$object *, struct _jc_java_awt_Component$object *);
extern void _jc_javax_swing_FocusManager$method$processKeyEvent$44dfe6771c38c557(_jc_env *, struct _jc_javax_swing_FocusManager$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_event_KeyEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_FocusManager$method_info$focusNextComponent$7bc09eefe16e9c64;
extern _jc_method _jc_javax_swing_FocusManager$method_info$focusPreviousComponent$693af46b828c4036;
extern _jc_method _jc_javax_swing_FocusManager$method_info$processKeyEvent$44dfe6771c38c557;

// Static methods
extern void _jc_javax_swing_FocusManager$method$disableSwingFocusManager$7ef84d03cf73af00(_jc_env *);
extern struct _jc_javax_swing_FocusManager$object *_jc_javax_swing_FocusManager$method$getCurrentManager$c06aa4e51807b32a(_jc_env *);
extern jboolean _jc_javax_swing_FocusManager$method$isFocusManagerEnabled$27024b029fe0e25b(_jc_env *);
extern void _jc_javax_swing_FocusManager$method$setCurrentManager$796ee04ef82e07b0(_jc_env *, struct _jc_javax_swing_FocusManager$object *);

// Virtual methods structure
struct _jc_javax_swing_FocusManager$vmethods {
	void	(*focusNextComponent$7bc09eefe16e9c64)(_jc_env *, struct _jc_javax_swing_FocusManager$object *, struct _jc_java_awt_Component$object *);
	void	(*focusPreviousComponent$693af46b828c4036)(_jc_env *, struct _jc_javax_swing_FocusManager$object *, struct _jc_java_awt_Component$object *);
	void	(*processKeyEvent$44dfe6771c38c557)(_jc_env *, struct _jc_javax_swing_FocusManager$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_event_KeyEvent$object *);
};

// Vtable
struct _jc_javax_swing_FocusManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_KeyboardFocusManager$vmethods	java_awt_KeyboardFocusManager;
	_jc_java_awt_DefaultKeyboardFocusManager$vmethods	java_awt_DefaultKeyboardFocusManager;
	_jc_javax_swing_FocusManager$vmethods	javax_swing_FocusManager;
};

// Vtype
struct _jc_javax_swing_FocusManager$vtype {
	_jc_type			type;
	_jc_javax_swing_FocusManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_FocusManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_FocusManager$refs {
    _jc_javax_swing_FocusManager$sub_refs	javax_swing_FocusManager;
    _jc_java_awt_DefaultKeyboardFocusManager$sub_refs	java_awt_DefaultKeyboardFocusManager;
    _jc_java_awt_KeyboardFocusManager$sub_refs	java_awt_KeyboardFocusManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_FocusManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_FocusManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_KeyboardFocusManager$sub_nonrefs	java_awt_KeyboardFocusManager;
    _jc_java_awt_DefaultKeyboardFocusManager$sub_nonrefs	java_awt_DefaultKeyboardFocusManager;
    _jc_javax_swing_FocusManager$sub_nonrefs	javax_swing_FocusManager;
};

// Object instance structure
struct _jc_javax_swing_FocusManager$object {
	_jc_javax_swing_FocusManager$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_FocusManager$vtype	*vtype;
	_jc_javax_swing_FocusManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_FocusManager$vtype _jc_javax_swing_FocusManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_FocusManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_FocusManager$class_object;

#endif	/* _JC_javax_swing_FocusManager_H_ */

==> jc-1.4.5.tar.gz: javax/swing/FocusManager.h <==
// public abstract class javax.swing.FocusManager

// class file dependencies
// @dep_class bd8f813050148ee1 java_awt_DefaultKeyboardFocusManager
// @dep_class 3c8264cdfd76a265 java_awt_KeyboardFocusManager
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6d7c3f688095f3e7 javax_swing_FocusManager

// header file dependencies
// @dep_header java_awt_DefaultKeyboardFocusManager

#include "java/awt/DefaultKeyboardFocusManager.h"

#ifndef _JC_javax_swing_FocusManager_H_
#define _JC_javax_swing_FocusManager_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_event_KeyEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_FocusManager$object;

// Typedefs
typedef struct _jc_javax_swing_FocusManager$sub_refs	_jc_javax_swing_FocusManager$sub_refs;
typedef struct _jc_javax_swing_FocusManager$sub_nonrefs	_jc_javax_swing_FocusManager$sub_nonrefs;
typedef struct _jc_javax_swing_FocusManager$refs	_jc_javax_swing_FocusManager$refs;
typedef struct _jc_javax_swing_FocusManager$nonrefs	_jc_javax_swing_FocusManager$nonrefs;
typedef struct _jc_javax_swing_FocusManager$object	_jc_javax_swing_FocusManager$object;

typedef struct _jc_javax_swing_FocusManager$fields_struct	_jc_javax_swing_FocusManager$fields_struct;
typedef const struct _jc_javax_swing_FocusManager$vmethods	_jc_javax_swing_FocusManager$vmethods;
typedef const struct _jc_javax_swing_FocusManager$vtable	_jc_javax_swing_FocusManager$vtable;
typedef const struct _jc_javax_swing_FocusManager$vtype	_jc_javax_swing_FocusManager$vtype;

// Class fields structure
struct _jc_javax_swing_FocusManager$fields_struct {
	struct _jc_java_lang_String$object	*FOCUS__5fMANAGER__5fCLASS__5fPROPERTY;
};
extern _jc_javax_swing_FocusManager$fields_struct _jc_javax_swing_FocusManager$class_fields;

// Constructors
extern void _jc_javax_swing_FocusManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_FocusManager$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_FocusManager$method$focusNextComponent$7bc09eefe16e9c64(_jc_env *, struct _jc_javax_swing_FocusManager$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_FocusManager$method$focusPreviousComponent$693af46b828c4036(_jc_env *, struct _jc_javax_swing_FocusManager$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_FocusManager$method$processKeyEvent$44dfe6771c38c557(_jc_env *, struct _jc_javax_swing_FocusManager$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_event_KeyEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_FocusManager$method_info$focusNextComponent$7bc09eefe16e9c64;
extern _jc_method _jc_javax_swing_FocusManager$method_info$focusPreviousComponent$693af46b828c4036;
extern _jc_method _jc_javax_swing_FocusManager$method_info$processKeyEvent$44dfe6771c38c557;

// Static methods
extern void _jc_javax_swing_FocusManager$method$disableSwingFocusManager$7ef84d03cf73af00(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_FocusManager$object *_jc_javax_swing_FocusManager$method$getCurrentManager$c06aa4e51807b32a(_jc_env *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_FocusManager$method$isFocusManagerEnabled$27024b029fe0e25b(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_FocusManager$method$setCurrentManager$796ee04ef82e07b0(_jc_env *, struct _jc_javax_swing_FocusManager$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_FocusManager$vmethods {
	void	(*focusNextComponent$7bc09eefe16e9c64)(_jc_env *, struct _jc_javax_swing_FocusManager$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	void	(*focusPreviousComponent$693af46b828c4036)(_jc_env *, struct _jc_javax_swing_FocusManager$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	void	(*processKeyEvent$44dfe6771c38c557)(_jc_env *, struct _jc_javax_swing_FocusManager$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_event_KeyEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_FocusManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_KeyboardFocusManager$vmethods	java_awt_KeyboardFocusManager;
	_jc_java_awt_DefaultKeyboardFocusManager$vmethods	java_awt_DefaultKeyboardFocusManager;
	_jc_javax_swing_FocusManager$vmethods	javax_swing_FocusManager;
};

// Vtype
struct _jc_javax_swing_FocusManager$vtype {
	_jc_type			type;
	_jc_javax_swing_FocusManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_FocusManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_FocusManager$refs {
    _jc_javax_swing_FocusManager$sub_refs	javax_swing_FocusManager;
    _jc_java_awt_DefaultKeyboardFocusManager$sub_refs	java_awt_DefaultKeyboardFocusManager;
    _jc_java_awt_KeyboardFocusManager$sub_refs	java_awt_KeyboardFocusManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_FocusManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_FocusManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_KeyboardFocusManager$sub_nonrefs	java_awt_KeyboardFocusManager;
    _jc_java_awt_DefaultKeyboardFocusManager$sub_nonrefs	java_awt_DefaultKeyboardFocusManager;
    _jc_javax_swing_FocusManager$sub_nonrefs	javax_swing_FocusManager;
};

// Object instance structure
struct _jc_javax_swing_FocusManager$object {
	_jc_javax_swing_FocusManager$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_FocusManager$vtype	*vtype;
	_jc_javax_swing_FocusManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_FocusManager$vtype _jc_javax_swing_FocusManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_FocusManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_FocusManager$class_object;

#endif	/* _JC_javax_swing_FocusManager_H_ */
